How to Participate
==================

Getting started
---------------

* Create account on `Github <https://github.com/openstack/savanna>`_
  (if you don't have one)

  * Make sure that your local git is properly configured by executing
    ``git config --list``. If not, configure ``user.name``, ``user.email``

* Create account on `Launchpad <https://launchpad.net/savanna>`_
  (if you don't have one)

* Subscribe to `OpenStack general mail-list <http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack>`_

* Subscribe to `OpenStack development mail-list <http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-dev>`_

* Create `OpenStack profile <https://www.openstack.org/profile/>`_

* Login to `OpenStack Gerrit <https://review.openstack.org/>`_ with your
  Launchpad id

  * Sign `OpenStack Individual Contributor License Agreement <https://review.openstack.org/#/settings/agreements>`_
  * Make sure that your email is listed in `identities <https://review.openstack.org/#/settings/web-identities>`_

* Subscribe to code-reviews. Go to your settings on http://review.openstack.org

  * Go to ``watched projects``
  * Add ``openstack/savanna``, ``openstack/savanna-dashboard``,
    ``openstack/savanna-extra``, ``openstack/python-savannaclient``,
    ``openstack/savanna-image-elements``


How to stay in touch with the community?
----------------------------------------

* If you have something to discuss use
  `OpenStack development mail-list <http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-dev>`_.
  Prefix mail subject with ``[Savanna]``

* Join ``#savanna`` IRC channel on `freenode <http://freenode.net/>`_

* Join public weekly meetings on *Thursdays at 18:00 UTC* on
  ``#openstack-meeting-alt`` IRC channel


How to send your first patch on review?
---------------------------------------

* Checkout Savanna code from `Github <https://github.com/openstack/savanna>`_

* Carefully read https://wiki.openstack.org/wiki/Gerrit_Workflow

  * Pay special attention to https://wiki.openstack.org/wiki/Gerrit_Workflow#Committing_Changes

* Apply and commit your changes

* Make sure that your code passes ``PEP8`` checks and unit-tests.
  See :doc:`development.guidelines`

* Send your patch on review

* Monitor status of your patch review on https://review.openstack.org/#/



